pub struct Error { /* private fields */ }Expand description
This type represents the possible errors when parsing S-expression data.
Implementations
Sourceimpl Error
impl Error
Sourcepub fn classify(&self) -> Category
pub fn classify(&self) -> Category
Categorizes the cause of this error.
Category::Io- failure to read or write bytes on an IO streamCategory::Syntax- input that is not a syntactically valid S-experssionCategory::Eof- unexpected end of the input data
Sourcepub fn is_io(&self) -> bool
pub fn is_io(&self) -> bool
Returns true if this error was caused by a failure to read or write bytes on an IO stream.